@@ -6,9 +6,13 @@ root = os.path.dirname(os.path.abspath(__file__))
 sys.path.append(root)
 
 import torch
+import warnings
 from ase import Atoms
 import ase.calculators.calculator
-from .batch_opt.ANI2xt import ANI2xt
+try:
+    from .batch_opt.ANI2xt import ANI2xt
+except:
+    warnings.warn("ANI2xt is not installed")
 import torchani
 from openbabel import pybel
 from tqdm import tqdm
